
# writing

## Release History

### 1.0.0
* Translate text and translate MD
* Convert MD to Audio and Video

...

## Setup and Install

```
pip install writing-nuuuwan
```

*The source code for this library can be found at https://github.com/nuuuwan/writing.*
